@@ -306,8 +306,8 @@ HRESULT InitDevice()
 
     // Setup the viewport
     D3D11_VIEWPORT vp;
-    vp.Width    = width;
-    vp.Height   = height;
+    vp.Width    = static_cast<FLOAT>(width);
+    vp.Height   = static_cast<FLOAT>(height);
     vp.MinDepth = 0.0f;
     vp.MaxDepth = 1.0f;
     vp.TopLeftX = 0;
@@ -430,7 +430,7 @@ HRESULT InitCg()
 
     CGpass myPass = cgGetFirstPass( myCgTechnique );
 
-    ID3DBlob * pVSBuf = cgD3D11GetIASignatureByPass( myPass );
+    ID3D10Blob * pVSBuf = cgD3D11GetIASignatureByPass( myPass );
 
     hr = g_pDevice->CreateInputLayout( layout, 1, pVSBuf->GetBufferPointer(), pVSBuf->GetBufferSize(), &g_pVertexLayout ); 
     if( hr != S_OK )
