@@ -314,8 +314,8 @@ HRESULT InitDevice()
 
     // Setup the viewport
     D3D11_VIEWPORT vp;
-    vp.Width    = width;
-    vp.Height   = height;
+    vp.Width    = static_cast<FLOAT>(width);
+    vp.Height   = static_cast<FLOAT>(height);
     vp.MinDepth = 0.0f;
     vp.MaxDepth = 1.0f;
     vp.TopLeftX = 0;
