@@ -75,15 +75,16 @@ static void DumpParameter(const char* pTitle, CGparameter parameter, int nParame
 static void DumpParameterValues(CGparameter parameter);
 static void DumpType(const char* pTitle, int index, CGtype type);
 
-const char* myProgramName = "cgfxcat";  /* Program name for messages. */
-char*       pFileName = NULL;
-CGprofile   myProfile = CG_PROFILE_UNKNOWN;
-char*       myProfileString = NULL;
-char*       myEntry = NULL;
-CGcontext   myCgContext = 0;
-CGtechnique myCgTechnique = 0;
-StateType   myStateType = STATE_TYPE_GENERIC;
-CgFileType  myFileType = CG_FILE_TYPE_UNKNOWN;
+const char*     myProgramName = "cgfxcat";  /* Program name for messages. */
+char*           pFileName = NULL;
+CGprofile       myProfile = CG_PROFILE_UNKNOWN;
+char*           myProfileString = NULL;
+char*           myEntry = NULL;
+CGcontext       myCgContext = 0;
+CGtechnique     myCgTechnique = 0;
+StateType       myStateType = STATE_TYPE_GENERIC;
+CgFileType      myFileType = CG_FILE_TYPE_UNKNOWN;
+CGGLglslversion myGlslVersion = CG_GL_GLSL_DEFAULT;
 
 /* HandleOptions modifies argv, so we need some fake ones for glutInit */
 
@@ -152,6 +153,13 @@ static void HandleOptions(int argc, char *argv[])
             } else {
                 ok = 0;
             }
+        } else if (!strcmp(argv[ii], "-glsl")) {
+            ++ii;
+            if (ii<argc) {
+                myGlslVersion = cgGLGetGLSLVersion(argv[ii]);
+            } else {
+                ok = 0;
+            }
         } else if (!pFileName) {
             pFileName = argv[ii];
             if (*pFileName == '-') {
@@ -257,7 +265,7 @@ static void GetProfileAndEntryFromObjectFile(const char *pFileName)
 
 static void PrintUsage(void)
 {
-    fprintf(stderr, "Usage: %s [-gl] [-effect] [-program] [-object] [-profile profile] [-entry entry] file\n", myProgramName);
+    fprintf(stderr, "Usage: %s [-gl] [-glsl version] [-effect] [-program] [-object] [-profile profile] [-entry entry] file\n", myProgramName);
 }
 
 int errorCount = 0;
@@ -302,6 +310,8 @@ static void InitContext(void)
         cgGLRegisterStates(myCgContext);
         CheckForCgError("registering GL state handlers");
 
+        cgGLSetContextGLSLVersion(myCgContext,myGlslVersion);
+        CheckForCgError("setting GLSL version");
     } else {
 
         RegisterStates(myCgContext);
@@ -1047,8 +1057,8 @@ static void DumpStateAssignment(CGstateassignment sa, int nStateAssignment, int
     case CG_PROGRAM_TYPE:
         program = cgGetProgramStateAssignmentValue(sa);
         tab_printf("Value: %i %s %s\n", PtrToUlong(program),
-                  cgGetProgramString(program, CG_PROGRAM_PROFILE),
-                  cgGetProgramString(program, CG_PROGRAM_ENTRY));
+                  program ? cgGetProgramString(program, CG_PROGRAM_PROFILE) : "",
+                  program ? cgGetProgramString(program, CG_PROGRAM_ENTRY) : "");
         break;
     case CG_FLOAT:
     case CG_FLOAT1:
@@ -1388,12 +1398,14 @@ static void DumpParameter(const char* pTitle, CGparameter parameter, int nParame
     CGparameter source;
     CGparameter connected;
     CGparameter structParameter;
+    CGparameter cbufferParameter;
     CGparameter arrayParameter;
     CGeffect effect;
     CGprogram program;
     CGstateassignment sa;
     CGtype type;
     const char* pSemantic;
+    const char* pBlockName;
     int ii;
     int nConnected;
     int nAnnotation;
@@ -1524,6 +1536,24 @@ static void DumpParameter(const char* pTitle, CGparameter parameter, int nParame
                           container, parent);
             structParameter = cgGetNextParameter(structParameter);
         }
+    } else if (type == CG_UNIFORMBUFFER) {
+        pBlockName = cgGetUniformBufferBlockName(parameter);
+        tab_printf("UniformBufferBlockName: %s\n", pBlockName);
+        if (program) {
+            tab_printf("NamedProgramUniformBuffer: %i\n",
+                  cgGetNamedProgramUniformBuffer(program, pBlockName));
+        }
+        if (effect) {
+            tab_printf("NamedEffectUniformBuffer: %i\n",
+                  cgGetNamedEffectUniformBuffer(effect, pBlockName));
+        }
+        cbufferParameter = cgGetFirstUniformBufferParameter(parameter);
+        nParameter = 0;
+        while (cbufferParameter) {
+            DumpParameter("UniformBufferParameter", cbufferParameter, ++nParameter,
+                          container, parent);
+            cbufferParameter = cgGetNextParameter(cbufferParameter);
+        }
     } else {
         tab_printf("Resource: %s %i\n",
              cgGetResourceString(cgGetParameterResource(parameter)),
